@@ -195,10 +195,6 @@ class FilterStepPerformer(StepPerformer):
     def step_display_name(cls) -> str:
         return "Filtered a Column"
 
-    @classmethod
-    def step_event_type(cls) -> str:
-        return "filter_column_edit"
-
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         """
@@ -235,7 +231,7 @@ class FilterStepPerformer(StepPerformer):
         )
 
         # If no errors we create a new step for this filter
-        post_state = deepcopy(prev_state)
+        post_state = prev_state.copy(deep_sheet_indexes=[sheet_index])
 
         # Execute the filter
         final_df, pandas_processing_time = _execute_filter(
